@@ -40,8 +40,8 @@ for directory in os.scandir(here):
                     globals()[name] = Instrument(modules=modules, name=name)
                 except:
                     name = sname
-                    # warnings.warn(f"{sname} not properly formatted, implement name and hwid and create a class to use properly.")
-                globals()[name] = module
+                    warnings.warn(f"{sname} not properly formatted, implement name and hwid and create a class to use properly.")
+                    globals()[name] = module
             except Exception as ex:
                 print(f"{file} import failed")
                 print(ex)
