@@ -1,6 +1,7 @@
 import pyvisa
 name = "esp300"
-hwid = [""]
+hwid = ["10C4:EA60"]
+serial_number = ["20210204471"]
 
 class ESP300:
     def __init__(self, port):
