@@ -29,6 +29,8 @@ class InstrumentWrapper(param.Parameterized):
         self.button.on_click(self.reload_devices)
         if "software_software" in self.devices.keys():
             self.instrument_selected = "software_software"
+        elif len(self.devices.keys()) == 1:
+            self.instrument_selected = self.devices.keys()[0]  # use only available option
 
     def reload_devices(self, event=None, debug=False):
         ports = find_ports()
@@ -46,7 +48,7 @@ class InstrumentWrapper(param.Parameterized):
                             print(hwid)
                             print(port.hwid.split(" ")[1].replace("VID:PID=", ""))
                         if str(hwid) == port.hwid.split(" ")[1].replace("VID:PID=", ""):
-                            name = f"{port.serial_number} - {port.name} - {mname}"
+                            name = f"{port.serial_number} - {port.name} - {mname} - {port.name}"
                             self.devices[name] = {"name": port.name, "hwid": port.hwid,
                                                   "serial_number": port.serial_number, "module": module, "port": port}
         self.param["instrument_selected"].objects = self.devices.keys()
@@ -58,6 +60,7 @@ class InstrumentWrapper(param.Parameterized):
             self.devices[self.instrument_selected]["port"])
 
     def view(self):
+
         return pn.Column(self.param, self.button)
 
     def serve(self):
